pytoxr
======

Open-source ToxR data analysis.

Transmembrane-domain interactions of proteins are vital for cellular function. 
ToxR, TOXCAT and dsTBL are powerful tools for investigating these interactions in natural membrane environment. 
The pytoxr module contains tools for the analysis of data from ToxR-based laboratory experiments.

Installation
------------
::

	pip install pytoxr
	
pytoxr requires python (tested for 3.x) with the standard scientific packages numpy, scipy, pandas, seaborn, and matplotlib.
Pip should also automatically install the eccpy package of Mark Teese (https://github.com/teese/eccpy).

Development Status
------------------

pytoxr has been used to analyse a small number of data files within our work group. 
Code is available to use without any guarantee or warranty. It has not been extensively tested.

Citation
--------

A peer-reviewed article is in preparation. 
For now, please reference as the "pytoxr package of Mark Teese, Technical University of Munich."

License
-------
This software is released under the permissive MIT license.

Contact
-------
For contact details, see the image below. 


Further contact details are available at my `staff page`__ within the `Langosch lab`__
of the Technical University of Munich.

.. _StaffPage: http://cbp.wzw.tum.de/index.php?id=49&L=1
.. _LangoschPage: http://cbp.wzw.tum.de/index.php?id=9

__ StaffPage_
__ LangoschPage_


.. image:: https://raw.githubusercontent.com/teese/eccpy/master/docs/images/signac_seine_bei_samois.png
   :height: 150px
   :width: 250px